@@ -33,6 +33,13 @@ class building:
         raise ValueError('Values of building/allowshell must be yes | no | ask')
 
 
+class remote:
+    '''Get configuration under [remote]'''
+    allowremote = config['remote'].getboolean('allowremote')
+    repositories = config['remote']['repositories']
+    remotecache = config['remote']['remotecache']
+
+
 class logging: 
     '''Get logging settings'''
     from os import devnull
